@@ -30,6 +30,7 @@ not removed.
 #include <time.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdbool.h>
 #include "adesub.h"
 
 
@@ -37,8 +38,6 @@ not removed.
 #define	EXIT_FAILURE 1
 #define	X 0
 #define	Y 1
-typedef	enum { FALSE, TRUE } bool;
-
 #define	DIM 2               /* Dimension of points */
 
 typedef	double tPointd[DIM];   /* Type double point */
@@ -85,7 +84,7 @@ void CheckAllSeg(int *nrow, int *ncol, double *tab, tPointd a, tPointd b, int *a
 /* X est le tableau des segments ; chaque ligne est un segment (xP,yP,xQ,yQ) */
 int i,j,n,p,k,temp;
 double **mat;
-tPointd c,d,crois;
+tPointd c,d;
 
 
 /* Memory allocation for local C variables */
@@ -239,8 +238,6 @@ Assumes it is already known that abc are collinear.
 ---------------------------------------------------------------------*/
 bool    Between( tPointd a, tPointd b, tPointd c )
 {
-   tPointd      ba, ca;
-
    /* If ab not vertical, check betweenness on x; else on y. */
    if ( a[X] != b[X] )
      return ((a[X] <= c[X]) && (c[X] <= b[X])) ||
